<?php
/**
 * Kalium WordPress Theme
 *
 * ACF Pro fields.
 *
 * @author Laborator
 * @link   https://kaliumtheme.com
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

add_action( 'acf/include_fields', function() {
	if ( ! function_exists( 'acf_add_local_field_group' ) ) {
		return;
	}

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c4875e914',
		'title' => 'Video Post Format Settings',
		'fields' => array(
			array(
				'key' => 'field_5502ead658c5a',
				'label' => 'Video Resolution',
				'name' => 'video_resolution',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Set the correct video resolution to make it fit inside the container (avoid black lines). <br />
You can also set width and height (i.e. 300x240).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '16:9',
				'placeholder' => 'Example: 16:9 or 3:4',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_5655d1425a392',
				'label' => 'Auto Play Video',
				'name' => 'auto_play_video',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Play video immediately when page loads.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
				array(
					'param' => 'post_format',
					'operator' => '==',
					'value' => 'video',
				),
			),
		),
		'menu_order' => 0,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c486ef604',
		'title' => 'Audio Post Format Settings',
		'fields' => array(
			array(
				'key' => 'field_5655d3df8c82d',
				'label' => 'Auto Play Audio',
				'name' => 'auto_play_audio',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Play audio immediately when page loads.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
				array(
					'param' => 'post_format',
					'operator' => '==',
					'value' => 'audio',
				),
			),
		),
		'menu_order' => 1,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c486f384b',
		'title' => 'Portfolio Item Type',
		'fields' => array(
			array(
				'key' => 'field_54c7b3e324244',
				'label' => 'Item Type',
				'name' => 'item_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select one of the portfolio styles.<br />
<small>Note: If you change the portfolio item type, you must click Update/Publish button in order to view item specific options.</small>',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'type-1' => 'Side Portfolio',
					'type-2' => 'Columned',
					'type-3' => 'Carousel',
					'type-4' => 'Zig Zag',
					'type-5' => 'Fullscreen',
					'type-6' => 'Lightbox',
					'type-7' => 'Design Your Own',
				),
				'default_value' => 'type-1',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
		),
		'menu_order' => 2,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c4870387e',
		'title' => 'Portfolio Settings',
		'fields' => array(
			array(
				'key' => 'field_54d8ebf646556',
				'label' => 'General Details',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54d8e04115822',
				'label' => 'Show Title & Description',
				'name' => 'show_title_description',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 1,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54d8d92895f3e',
				'label' => 'Custom Query',
				'name' => 'custom_query',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Manually select portfolio items to show in the list. If none is selected then all portfolio items will be shown. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54e49cbd3fbd1',
				'label' => 'Masonry Style Portfolio',
				'name' => 'masonry_style_portfolio',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Create custom box sizes for each portfolio item. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Masonry Mode',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_5d4abc087d9ce',
				'label' => 'Default Filter Category',
				'name' => 'default_filter_category',
				'aria-label' => '',
				'type' => 'taxonomy',
				'instructions' => 'Set default category to filter portfolio items at first page load.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'taxonomy' => 'portfolio_category',
				'field_type' => 'select',
				'allow_null' => 1,
				'add_term' => 0,
				'save_terms' => 0,
				'load_terms' => 0,
				'return_format' => 'object',
				'multiple' => 0,
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_5d4ac0a24acba',
				'label' => 'Hide "All" filter link from portfolio',
				'name' => 'filter_category_hide_all',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5d4abc087d9ce',
							'operator' => '!=empty',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54d8ebd746555',
				'label' => 'Grid Settings',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54d8ec0346557',
				'label' => 'Columns Count',
				'name' => 'columns_count',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set portfolio columns count for items.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					1 => '1 Item per Row',
					2 => '2 Items per Row',
					3 => '3 Items per Row',
					4 => '4 Items per Row',
					5 => '5 Items per Row',
					6 => '6 Items per Row',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d91396c63e1',
				'label' => 'Reveal Effect',
				'name' => 'reveal_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select effect to apply to thumbnail elements.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'none' => 'None',
					'fade' => 'Fade',
					'slidenfade' => 'Slide and Fade',
					'zoom' => 'Zoom In',
					'fade-one' => 'Fade (one by one)',
					'slidenfade-one' => 'Slide and Fade (one by one)',
					'zoom-one' => 'Zoom In (one by one)',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_572c8fb271fa6',
				'label' => 'Full-width Container',
				'name' => 'portfolio_full_width',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Extend portfolio container to the browser edge.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_572c900371fa7',
				'label' => 'Title and Filter Container',
				'name' => 'portfolio_full_width_title_container',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Include title and filter within container.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_572c8fb271fa6',
							'operator' => '==',
							'value' => 'yes',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No (Full-width)',
				),
				'default_value' => 'yes',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db3f22143c1',
				'label' => 'Layout Type',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54db3f3c143c2',
				'label' => 'Layout Type',
				'name' => 'layout_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select layout type to use for this portfolio page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'type-1' => 'Thumbnails with Visible Titles',
					'type-2' => 'Thumbnails with Titles Inside',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5530fb8a8c2de',
				'label' => 'Dynamic Image Height',
				'name' => 'portfolio_type_1_dynamic_image_height',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Use proportional image height for each item.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db52dcf2edb',
				'label' => 'Thumbnail Hover Effect',
				'name' => 'portfolio_type_1_thumbnail_hover_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set thumbnail hover effect for this portfolio page.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'none' => 'No hover effect',
					'full' => 'Full background hover',
					'distanced' => 'Distanced background hover',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db53c5e96dc',
				'label' => 'Custom Hover Background Color',
				'name' => 'portfolio_type_1_custom_hover_background_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Apart from defined color styles you can select your own custom color for the hover effect.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_54db6aca2befa',
				'label' => 'Dynamic Image Height',
				'name' => 'portfolio_type_2_dynamic_image_height',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Use proportional image height for each item.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db4b9bc3352',
				'label' => 'Grid Spacing',
				'name' => 'portfolio_type_2_grid_spacing',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Spacing between portfolio items.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'normal' => 'Default spacing',
					'merged' => 'Merged (no spacing)',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db4dbd94c7d',
				'label' => 'Thumbnail Hover Effect',
				'name' => 'portfolio_type_2_thumbnail_hover_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set thumbnail hover effect for this portfolio page.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'none' => 'No hover effect',
					'full' => 'Full background hover',
					'distanced' => 'Distanced background hover',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db9624e3b96',
				'label' => 'Thumbnail Hover Text Position',
				'name' => 'portfolio_type_2_thumbnail_hover_text_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Override text position for hover layer.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'top-left' => 'Top Left',
					'top-right' => 'Top Right',
					'center' => 'Center',
					'bottom-left' => 'Bottom Left',
					'bottom-right' => 'Bottom Right',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db4f000d243',
				'label' => 'Thumbnail Hover Style',
				'name' => 'portfolio_type_2_thumbnail_hover_style',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select thumbnail hover background style for this portfolio page.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'primary' => 'Primary theme color',
					'black' => 'Black background',
					'white' => 'White background',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db5045cf3bd',
				'label' => 'Custom Hover Background Color',
				'name' => 'portfolio_type_2_custom_hover_background_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Apart from defined color styles you can select your own custom color for the hover effect.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54db3f3c143c2',
							'operator' => '==',
							'value' => 'type-2',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_54da0e5ecf168',
				'label' => 'Custom Query',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54d8d99c01093',
				'label' => 'Portfolio Items',
				'name' => 'portfolio_items',
				'aria-label' => '',
				'type' => 'relationship',
				'instructions' => 'Select portfolio items to include in the query.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'post_type' => array(
					0 => 'portfolio',
				),
				'taxonomy' => '',
				'filters' => array(
					0 => 'search',
				),
				'elements' => array(
					0 => 'featured_image',
				),
				'min' => '',
				'max' => '',
				'return_format' => 'id',
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_54da0a7a88fe9',
				'label' => 'Select From Category',
				'name' => 'select_from_category',
				'aria-label' => '',
				'type' => 'taxonomy',
				'instructions' => 'Select portfolio items from specific category/categories. Note: This will ignore selected items from above option "Portfolio Items".',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'taxonomy' => 'portfolio_category',
				'field_type' => 'checkbox',
				'add_term' => 1,
				'save_terms' => 0,
				'load_terms' => 0,
				'return_format' => 'id',
				'multiple' => 0,
				'allow_null' => 0,
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_5724861a9cc86',
				'label' => 'Select From Tags',
				'name' => 'select_from_tags',
				'aria-label' => '',
				'type' => 'taxonomy',
				'instructions' => 'Select portfolio items from specific tag/tags. Note: This will ignore selected items from above option "Portfolio Items".',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'taxonomy' => 'portfolio_tag',
				'field_type' => 'checkbox',
				'add_term' => 1,
				'save_terms' => 0,
				'load_terms' => 0,
				'return_format' => 'id',
				'multiple' => 0,
				'allow_null' => 0,
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_54da065e1a6ae',
				'label' => 'Order By',
				'name' => 'order_by',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set order by field for the selected posts.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					': Default' => ': Default',
					'post__in' => 'List order',
					'date' => 'Date',
					'rand' => 'Random',
					'menu_order' => 'Menu Order',
				),
				'default_value' => 'post__in',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54da072c1a6af',
				'label' => 'Order',
				'name' => 'order',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Order direction (possible values: Ascending / Descending).',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d8d92895f3e',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'asc' => 'Ascending (ASC)',
					'desc' => 'Descending (DESC)',
				),
				'default_value' => 'asc',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d9f09775823',
				'label' => 'Items per Page',
				'name' => 'items_per_page',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set how many portfolio items you want to show per page (leave empty to use WordPress default)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => 'Leave empty to use default WordPress count',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_57275708bea44',
				'label' => 'Number of Items to Fetch',
				'name' => 'endless_per_page',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Note: Apart from "Items per Page", you can set custom number of items to fetch when "Show More" is clicked. (Optional)<br>
<small>This option is applied only when "endless pagination" is selected.</small>',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_54e49d5dd71c4',
				'label' => 'Masonry Items',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54e49cbd3fbd1',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54e49d71d71c5',
				'label' => 'How to use it',
				'name' => '',
				'aria-label' => '',
				'type' => 'message',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'message' => 'Note: Each portfolio box can have custom size. You must add portfolio items manually one by one. Masonry grid is <strong>12-columns</strong> based so keep in mind to fill the columns properly and not leave gaps.',
				'new_lines' => 'wpautop',
				'esc_html' => 0,
			),
			array(
				'key' => 'field_54e49e1dd7d45',
				'label' => 'Portfolio Items',
				'name' => 'masonry_items_list',
				'aria-label' => '',
				'type' => 'repeater',
				'instructions' => 'Select portfolio items to display. Drag items to change their order in list. Duplicated posts will be removed.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'collapsed' => '',
				'min' => 0,
				'max' => 0,
				'layout' => 'row',
				'button_label' => 'Add Row',
				'rows_per_page' => 20,
				'sub_fields' => array(
					array(
						'key' => 'field_54e4aac3ad53d',
						'label' => 'Row of Items',
						'name' => 'items_row',
						'aria-label' => '',
						'type' => 'repeater',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'collapsed' => '',
						'min' => 0,
						'max' => 0,
						'layout' => 'table',
						'button_label' => 'Add Item',
						'rows_per_page' => 20,
						'parent_repeater' => 'field_54e49e1dd7d45',
						'sub_fields' => array(
							array(
								'key' => 'field_54e4ad65ad540',
								'label' => 'Item',
								'name' => 'item',
								'aria-label' => '',
								'type' => 'post_object',
								'instructions' => '',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'post_type' => array(
									0 => 'portfolio',
								),
								'taxonomy' => '',
								'allow_null' => 0,
								'multiple' => 0,
								'return_format' => 'object',
								'ui' => 1,
								'bidirectional_target' => array(
								),
								'parent_repeater' => 'field_54e4aac3ad53d',
							),
							array(
								'key' => 'field_54e4ad76ad541',
								'label' => 'Box Size',
								'name' => 'box_size',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => '',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'12x4' => '12 col - small',
									'12x5' => '12 col - medium',
									'12x6' => '12 col - large',
									'9x3' => '9 col - small',
									'9x4' => '9 col - medium',
									'9x6' => '9 col - large',
									'8x3' => '8 col - small',
									'8x4' => '8 col - medium',
									'8x6' => '8 col - large',
									'6x3' => '6 col - small',
									'6x4' => '6 col - medium',
									'6x6' => '6 col - large',
									'5x3' => '5 col - small',
									'5x4' => '5 col - medium',
									'5x6' => '5 col - large',
									'4x3' => '4 col - small',
									'4x4' => '4 col - medium',
									'4x6' => '4 col - large',
									'3x3' => '3 col - small',
									'3x4' => '3 col - medium',
									'3x6' => '3 col - large',
								),
								'default_value' => '4x3',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
								'parent_repeater' => 'field_54e4aac3ad53d',
							),
						),
					),
				),
			),
			array(
				'key' => 'field_572750e1c944d',
				'label' => 'Items per Page',
				'name' => 'masonry_items_per_page',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set how many portfolio items you want to show per page (by default all masonry items will show)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_572754d33933b',
				'label' => 'Number of Items to Fetch',
				'name' => 'masonry_endless_per_page',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Note: Apart from "Items per Page", you can set custom number of items to fetch when "Show More" is clicked. (Optional)<br>
<small>This option is applied only when "endless pagination" is selected.</small>',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'page_template',
					'operator' => '==',
					'value' => 'portfolio.php',
				),
			),
		),
		'menu_order' => 3,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48759d39',
		'title' => 'Post Slider Images',
		'fields' => array(
			array(
				'key' => 'field_5502a7cfce21c',
				'label' => 'Post Slider Images',
				'name' => 'post_slider_images',
				'aria-label' => '',
				'type' => 'gallery',
				'instructions' => 'Add your gallery images here.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'array',
				'preview_size' => 'medium',
				'insert' => 'append',
				'library' => 'all',
				'min' => '',
				'max' => '',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
				array(
					'param' => 'post_format',
					'operator' => '==',
					'value' => 'gallery',
				),
			),
		),
		'menu_order' => 4,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48768d0b',
		'title' => 'Side Portfolio (Portfolio Type 1)',
		'fields' => array(
			array(
				'key' => 'field_54c8cd2c53942',
				'label' => 'Item Description Alignment',
				'name' => 'item_description_alignment',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set the alignment of description block that contains item details.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'left' => 'Left',
					'right' => 'Right',
				),
				'default_value' => 'left',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54c8cfe8be8a8',
				'label' => 'Item Description Width',
				'name' => 'item_description_width',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set the description width (columns) to occupy in item page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'1-4' => 'One fourth (1/4)',
					'1-3' => 'One third (1/3)',
					'1-2' => 'Half width (1/2)',
				),
				'default_value' => '1-3',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54cba2ef32236',
				'label' => 'Gallery Type',
				'name' => 'gallery_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set placement for gallery images.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inline' => 'Inline with the content',
					'fullbg' => 'Full background',
				),
				'default_value' => 'inline',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d8c4ec258c1',
				'label' => 'Stick Photos to Top',
				'name' => 'gallery_stick_to_top',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Stick gallery photos to the top of page.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54cba2ef32236',
							'operator' => '==',
							'value' => 'fullbg',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Stick',
				'default_value' => 1,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54ca5e82cfe95',
				'label' => 'Sticky Description',
				'name' => 'sticky_description',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Make description container sticky when scrolling down the page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Yes',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_55785d792a0b4',
				'label' => 'Masonry Mode Gallery',
				'name' => 'masonry_mode_gallery',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you want to use masonry layout for gallery items which helps ordering the images, leaving no extra gaps.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-1',
				),
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
		),
		'menu_order' => 5,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48780e3d',
		'title' => 'Columned (Portfolio Type 2)',
		'fields' => array(
			array(
				'key' => 'field_54cf8576bec0d',
				'label' => 'Layout Type',
				'name' => 'layout_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'In this portfolio type you can choose between variants of the heading information.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default Layout',
					'centered' => 'Centered Content Layout',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5ea5811e767fb',
				'label' => 'Gallery Position',
				'name' => 'gallery_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set gallery position in relation with item description.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'below-description' => 'Below description',
					'above-description' => 'Above description',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54cfc462777bb',
				'label' => 'Share and Like Position',
				'name' => 'share_and_like_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'This is applied only if you have allowed item sharing and portfolio likes.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'before' => 'Before gallery',
					'after' => 'After gallery (in the end)',
				),
				'default_value' => 'before',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54cfdbd865d6e',
				'label' => 'Full-width Gallery',
				'name' => 'full_width_gallery',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Shown gallery container in full width size.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Yes',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54d0d51d9950d',
				'label' => 'Show Featured Image',
				'name' => 'show_featured_image',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Check this box if you want to show featured image above the post title.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Yes',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_565eee77b12a7',
				'label' => 'Full-width Featured Image',
				'name' => 'fullwidth_featured_image',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Make this image full width, other elements will not be affected by this option.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d0d51d9950d',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_564d92c32776f',
				'label' => 'Title Position',
				'name' => 'title_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You have chosen to show featured image for this item, this option allows you to set the position of title.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d0d51d9950d',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'before' => 'Before featured image',
					'after' => 'After featured image',
				),
				'default_value' => 'after',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_570f468d87a3b',
				'label' => 'Masonry Mode Gallery',
				'name' => 'masonry_mode_gallery',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Enable this option if you want to use masonry layout for gallery items which helps ordering the images, leaving no extra gaps.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-2',
				),
			),
		),
		'menu_order' => 6,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48790af7',
		'title' => 'Carousel (Portfolio Type 3)',
		'fields' => array(
			array(
				'key' => 'field_54d21cac45fc0',
				'label' => 'Layout Type',
				'name' => 'layout_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'In this portfolio type you can choose between variants of the heading information.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default Layout',
					'centered' => 'Centered Content Layout',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-3',
				),
			),
		),
		'menu_order' => 7,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48794e83',
		'title' => 'Zig Zag (Portfolio Type 4)',
		'fields' => array(
			array(
				'key' => 'field_54d36361b2d95',
				'label' => 'Layout Type',
				'name' => 'layout_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'In this portfolio type you can choose between variants of the heading information.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default Layout',
					'centered' => 'Centered Content Layout',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5747fa6857004',
				'label' => 'Share and Like Position',
				'name' => 'share_and_like_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'This is applied only if you have allowed item sharing and portfolio likes.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'before' => 'Before gallery',
					'after' => 'After gallery (in the end)',
				),
				'default_value' => 'before',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-4',
				),
			),
		),
		'menu_order' => 8,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c4879adbe',
		'title' => 'Fullscreen (Portfolio Type 5)',
		'fields' => array(
			array(
				'key' => 'field_54d4e1c18e68b',
				'label' => 'Item Description Visibility',
				'name' => 'item_description_visibility',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Choose if you want to have description expanded by default or collapsed.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'collapsed' => 'Collapsed by default',
					'expanded' => 'Expanded by default',
				),
				'default_value' => 'collapsed',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_55770c3ae6b6e',
				'label' => 'Show Project Info Text',
				'name' => 'show_project_info_text',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Apart from "Click here to show project info" you can write your own caption.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => 'Click here to show project info',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_55770da7913bd',
				'label' => 'Hide Project Description',
				'name' => 'hide_project_description',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Force hiding the info box in this portfolio item only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-5',
				),
			),
		),
		'menu_order' => 9,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c487a27c2',
		'title' => 'Lightbox (Portfolio Type 6)',
		'fields' => array(
			array(
				'key' => 'field_565b16e5f8220',
				'label' => 'Content to Show',
				'name' => 'content_to_show',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select what content type to show in Lightbox when user clicks on thumbnail.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'featured-image' => 'Featured Image',
					'other-image' => 'Custom Image',
					'gallery' => 'Multiple Images and/or Video Gallery',
					'self-hosted-video' => 'Self-Hosted Video',
					'youtube' => 'YouTube',
					'vimeo' => 'Vimeo',
				),
				'default_value' => 'featured-image',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_565b1856f8221',
				'label' => 'Custom Image',
				'name' => 'custom_image',
				'aria-label' => '',
				'type' => 'image',
				'instructions' => 'Select or upload custom image to show for this item.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'other-image',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => 'retina-thumbnail',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'id',
				'preview_size' => 'medium',
				'library' => 'all',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
			array(
				'key' => 'field_565c8e0b8b789',
				'label' => 'Multiple Images & Video Gallery',
				'name' => 'image_and_video_gallery',
				'aria-label' => '',
				'type' => 'gallery',
				'instructions' => 'Select images (and/or videos) to attach to this item lightbox.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'gallery',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'array',
				'preview_size' => 'medium',
				'insert' => 'append',
				'library' => 'all',
				'min' => '',
				'max' => '',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
			array(
				'key' => 'field_565da645af380',
				'label' => 'Self-Hosted Video',
				'name' => 'self_hosted_video',
				'aria-label' => '',
				'type' => 'file',
				'instructions' => 'Select video from media gallery. Note: No other file types are supported in this field.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'self-hosted-video',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'array',
				'library' => 'all',
				'min_size' => '',
				'max_size' => '',
				'mime_types' => '',
			),
			array(
				'key' => 'field_565da8c58f047',
				'label' => 'YouTube Video URL',
				'name' => 'youtube_video_url',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Enter YouTube video URL.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'youtube',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_565da92b8f048',
				'label' => 'Vimeo Video URL',
				'name' => 'vimeo_video_url',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Enter Vimeo video URL.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'vimeo',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_565da86d8f044',
				'label' => 'Video Poster',
				'name' => 'video_poster',
				'aria-label' => '',
				'type' => 'image',
				'instructions' => 'Select image to show as video poster for this video.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'self-hosted-video',
						),
					),
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'vimeo',
						),
					),
					array(
						array(
							'field' => 'field_565b16e5f8220',
							'operator' => '==',
							'value' => 'youtube',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => 'retina-thumbnail',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'id',
				'preview_size' => 'medium',
				'library' => 'all',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-6',
				),
			),
		),
		'menu_order' => 10,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c487b1831',
		'title' => 'General Details',
		'fields' => array(
			array(
				'key' => 'field_572dca6076f77',
				'label' => 'Item Details',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54cb9c2d4d383',
				'label' => 'Sub Title',
				'name' => 'sub_title',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'One line title to describe the item (optional).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_572dca7376f78',
				'label' => 'Prev-Next Navigation',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_572dcd7dca870',
				'label' => 'Custom Prev-Next Links',
				'name' => 'custom_prevnext_links',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Enable custom navigation (prev/next) links for this portfolio item.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_572dc9d0b7458',
				'label' => 'Previous Item',
				'name' => 'prevnext_previous_id',
				'aria-label' => '',
				'type' => 'post_object',
				'instructions' => 'Set custom "previous" link for this portfolio item. (Optional)',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_572dcd7dca870',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'post_type' => array(
					0 => 'portfolio',
				),
				'taxonomy' => '',
				'allow_null' => 1,
				'multiple' => 0,
				'return_format' => 'object',
				'ui' => 1,
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_572dca8576f79',
				'label' => 'Next item',
				'name' => 'prevnext_next_id',
				'aria-label' => '',
				'type' => 'post_object',
				'instructions' => 'Set custom "next" link for this portfolio item. (Optional)',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_572dcd7dca870',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'post_type' => array(
					0 => 'portfolio',
				),
				'taxonomy' => '',
				'allow_null' => 1,
				'multiple' => 0,
				'return_format' => 'object',
				'ui' => 1,
				'bidirectional_target' => array(
				),
			),
			array(
				'key' => 'field_57b30c9744753',
				'label' => 'Custom Archive URL',
				'name' => 'custom_archive_url',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Enter custom URL to replace the default portfolio archive URL (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => 'http://',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
		),
		'menu_order' => 11,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c487ca369',
		'title' => 'Project Link',
		'fields' => array(
			array(
				'key' => 'field_54cb9b638f6c0',
				'label' => 'Launch Link Title',
				'name' => 'launch_link_title',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Usually written "Launch website"',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => 'Launch website',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_54cb9b9a8f6c1',
				'label' => 'Link URL',
				'name' => 'launch_link_href',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Website when users click in Launch Link (if not given will not be visible to the user).<br>
<em>Hint: If you want to disable clicking for this item, just type <strong>#</strong> in this field, and select <strong>Redirect to Link URL (Project URL)</strong> value in <strong>Item Linking</strong>.</em>',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => 'http://',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_54cb9bab8f6c2',
				'label' => 'Link Target',
				'name' => 'new_window',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Open in new tab or window when user clicks in link.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Open in new window',
				'default_value' => 1,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_55311147850c2',
				'label' => 'Item Linking',
				'name' => 'item_linking',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Apart from default item single page you can send users to the external source url (optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'single' => 'Continue on Single Page',
					'external' => 'Redirect to Link URL (Project URL)',
				),
				'default_value' => 'single',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-1',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-2',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-3',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-4',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-5',
				),
			),
		),
		'menu_order' => 12,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c487d4320',
		'title' => 'Checklists',
		'fields' => array(
			array(
				'key' => 'field_54cb998106890',
				'label' => 'Checklists',
				'name' => 'checklists',
				'aria-label' => '',
				'type' => 'repeater',
				'instructions' => 'Add custom checklists for example the services you have finished, tasks done, etc.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'collapsed' => '',
				'min' => 0,
				'max' => 0,
				'layout' => 'row',
				'button_label' => 'New Checklist',
				'rows_per_page' => 20,
				'sub_fields' => array(
					array(
						'key' => 'field_54cb99aa06891',
						'label' => 'Checklist Title',
						'name' => 'checklist_title',
						'aria-label' => '',
						'type' => 'text',
						'instructions' => 'Title to describe the checklist items.',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 2,
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
						'parent_repeater' => 'field_54cb998106890',
					),
					array(
						'key' => 'field_54cb99b306892',
						'label' => 'Checklist',
						'name' => 'checklist',
						'aria-label' => '',
						'type' => 'textarea',
						'instructions' => 'Enter one task per line, as many as you want.',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 2,
						'default_value' => '',
						'placeholder' => '',
						'maxlength' => '',
						'rows' => 5,
						'new_lines' => '',
						'parent_repeater' => 'field_54cb998106890',
					),
					array(
						'key' => 'field_54cb99d606893',
						'label' => 'Column Width',
						'name' => 'column_width',
						'aria-label' => '',
						'type' => 'select',
						'instructions' => 'Select columns per row for this checklist entry.',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'choices' => array(
							'1-1' => 'Full width',
							'1-2' => '50% Column',
						),
						'default_value' => '1-1',
						'allow_null' => 0,
						'multiple' => 0,
						'ui' => 0,
						'return_format' => 'value',
						'ajax' => 0,
						'placeholder' => '',
						'parent_repeater' => 'field_54cb998106890',
					),
				),
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-1',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-2',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-3',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-4',
				),
			),
			array(
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-5',
				),
			),
		),
		'menu_order' => 13,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c487e4256',
		'title' => 'Project Gallery',
		'fields' => array(
			array(
				'key' => 'field_54cb8f6397f6f',
				'label' => 'Images Reveal Effect',
				'name' => 'images_reveal_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Choose the effect to show the item images when they appear in viewport.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'none' => 'None',
					'fade' => 'Fade',
					'slidenfade' => 'Slide and Fade',
				),
				'default_value' => 'slidenfade',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54cb8f7d97f70',
				'label' => 'Image Spacing',
				'name' => 'image_spacing',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You can either set default image spacing or remove it (merge images).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default spacing',
					'nospacing' => 'No spacing (merged)',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5851592e0dd2f',
				'label' => 'Image Captions Position',
				'name' => 'image_captions_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set image captions position for gallery images.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'hover' => 'On hover',
					'below' => 'Below image',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_57a1e94ec8e20',
				'label' => 'Gallery Columns Gap',
				'name' => 'gallery_columns_gap',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54cb8f7d97f70',
							'operator' => '==',
							'value' => 'default',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => 'Default columns gap: 30 pixels',
				'prepend' => '',
				'append' => 'px',
				'min' => 0,
				'max' => '',
				'step' => 1,
			),
			array(
				'key' => 'field_54cb8fc197f71',
				'label' => 'Gallery',
				'name' => 'gallery',
				'aria-label' => '',
				'type' => 'flexible_content',
				'instructions' => 'Select all images you want to show for this portfolio item.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'layouts' => array(
					'layout_5ba0c487e96e0' => array(
						'key' => 'layout_5ba0c487e96e0',
						'name' => 'image',
						'label' => 'Image',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cb900997f72',
								'label' => 'Image',
								'name' => 'image',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Image that will be shown',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '60',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cb903397f73',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e96e7' => array(
						'key' => 'layout_5ba0c487e96e7',
						'name' => 'images_slider',
						'label' => 'Images Slider',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cfacf090383',
								'label' => 'Images',
								'name' => 'images',
								'aria-label' => '',
								'type' => 'gallery',
								'instructions' => 'Select images to include in the slider',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'insert' => 'append',
								'library' => 'all',
								'min' => '',
								'max' => '',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cfad5ffe36e',
								'label' => 'Auto Switch',
								'name' => 'auto_switch',
								'aria-label' => '',
								'type' => 'number',
								'instructions' => 'Set the number of seconds to auto rotate the images',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'default_value' => '',
								'placeholder' => '0 - By default its disabled',
								'prepend' => '',
								'append' => '',
								'min' => 0,
								'max' => '',
								'step' => 1,
							),
							array(
								'key' => 'field_54cfaccc90382',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e96eb' => array(
						'key' => 'layout_5ba0c487e96eb',
						'name' => 'comparison_images',
						'label' => 'Comparison Images',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cbad98dfbf1',
								'label' => 'Image 1',
								'name' => 'image_1',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Assign first image to compare (after)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '30',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cbadcddfbf2',
								'label' => 'Image 2',
								'name' => 'image_2',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Assign second image to compare (before)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '30',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cbadf5dfbf3',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e96ef' => array(
						'key' => 'layout_5ba0c487e96ef',
						'name' => 'youtube_video',
						'label' => 'YouTube Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccacb63b7a2',
								'label' => 'Video URL',
								'name' => 'video_url',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Enter YouTube video URL',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccace109b54',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccae1f11501',
								'label' => 'Video Poster',
								'name' => 'video_poster',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'You can assign video thumbnail (optional)',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_54cb8f6397f6f',
											'operator' => '!=',
											'value' => 'none',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_5653182ac91f2',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_565319185d634',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_5653118216551',
								'label' => 'Default YouTube Player',
								'name' => 'default_youtube_player',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Use YouTube default video player',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54ccac8c3b7a1',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e9705' => array(
						'key' => 'layout_5ba0c487e9705',
						'name' => 'vimeo_video',
						'label' => 'Vimeo Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccbeeff2d34',
								'label' => 'Video URL',
								'name' => 'video_url',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Enter Vimeo video URL',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccbeeff2d35',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_5a967257ae8d3',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_5a967285ae8d4',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54ccbeeff2d38',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e9709' => array(
						'key' => 'layout_5ba0c487e9709',
						'name' => 'selfhosted_video',
						'label' => 'Self-Hosted Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccc5b6dd8e6',
								'label' => 'Video',
								'name' => 'video_file',
								'aria-label' => '',
								'type' => 'file',
								'instructions' => 'Upload your own video or select from gallery',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'library' => 'all',
								'min_size' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54ccc5b6dd8e7',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccc5b6dd8e9',
								'label' => 'Video Poster',
								'name' => 'video_poster',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'You can assign video thumbnail (optional)',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_54cb8f6397f6f',
											'operator' => '!=',
											'value' => 'none',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_56531b176a96d',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_56531ba527a4e',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54ccc5b6dd8ea',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e970e' => array(
						'key' => 'layout_5ba0c487e970e',
						'name' => 'text_quote',
						'label' => 'Text Quote',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cfa12b726b2',
								'label' => 'Quote Text',
								'name' => 'quote_text',
								'aria-label' => '',
								'type' => 'textarea',
								'instructions' => 'Enter the quote text to display in portfolio gallery',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'maxlength' => '',
								'rows' => 5,
								'new_lines' => 'br',
							),
							array(
								'key' => 'field_54cfa18bdb105',
								'label' => 'Quote Author',
								'name' => 'quote_author',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'You may or may not include author name for this quote',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54cfa10e726b1',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c487e9711' => array(
						'key' => 'layout_5ba0c487e9711',
						'name' => 'html',
						'label' => 'HTML',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_565f2603583c9',
								'label' => 'Content',
								'name' => 'content',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'You can also use shortcodes in this field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 1,
								'delay' => 0,
							),
							array(
								'key' => 'field_565f2691583cb',
								'label' => 'Column Width',
								'name' => 'column_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Columns for image relative to container',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'1-1' => 'Full width (1/1)',
									'1-2' => 'Half width (1/2)',
									'1-3' => 'One third (1/3)',
									'2-3' => 'Two thirds (2/3)',
									'1-4' => 'One fourth (1/4)',
								),
								'default_value' => '1-1',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
				),
				'button_label' => 'Add New',
				'min' => '',
				'max' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-1',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-2',
				),
			),
		),
		'menu_order' => 14,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48846cf6',
		'title' => 'Project Gallery',
		'fields' => array(
			array(
				'key' => 'field_54d217367778f',
				'label' => 'Images Reveal Effect',
				'name' => 'images_reveal_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Choose the effect to show the item images when they appear in viewport.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'none' => 'None',
					'fade' => 'Fade',
					'slidenfade' => 'Slide and Fade',
				),
				'default_value' => 'slidenfade',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d2542caebc1',
				'label' => 'Image Spacing',
				'name' => 'image_spacing',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You can either set default image spacing or remove it (merge images).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default spacing',
					'nospacing' => 'No spacing (merged)',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_585162bf9c836',
				'label' => 'Image Captions Position',
				'name' => 'image_captions_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set image captions position for gallery images.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'hover' => 'On hover',
					'below' => 'Below image',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_57a1ea5e7767d',
				'label' => 'Gallery Columns Gap',
				'name' => 'gallery_columns_gap',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54d2542caebc1',
							'operator' => '==',
							'value' => 'default',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => 'Default columns gap: 30 pixels',
				'prepend' => '',
				'append' => 'px',
				'min' => 0,
				'max' => '',
				'step' => 1,
			),
			array(
				'key' => 'field_5703cbe608139',
				'label' => 'Maximum Image Height',
				'name' => 'maximum_image_height',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => '<strong>Optional:</strong> You can set maximum height for images in carousel. Setting value <strong>-1</strong> will show original image height.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => -1,
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_5703d1958031a',
				'label' => 'Carousel Start Position',
				'name' => 'carousel_start_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select starting position of images to show. By default carousel sets image starting position on center.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'center' => 'Center',
					'left' => 'Left',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d2123e0e72c',
				'label' => 'Infinite Loop Slides',
				'name' => 'infinite_loop_slides',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Checking this box will make carousel infinite loop when user clicks next/prev buttons.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Yes',
				'default_value' => 0,
				'ui' => 0,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54d214c4f5a7f',
				'label' => 'Auto Play',
				'name' => 'auto_play',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set number of seconds to automatically change the slides. Leave empty to disable.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => 7,
				'placeholder' => '',
				'prepend' => 'Seconds:',
				'append' => '',
				'min' => 0,
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_54d0e0254c737',
				'label' => 'Gallery',
				'name' => 'gallery',
				'aria-label' => '',
				'type' => 'flexible_content',
				'instructions' => 'Select all images you want to show for this portfolio item.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'layouts' => array(
					'layout_5ba0c4884a6b6' => array(
						'key' => 'layout_5ba0c4884a6b6',
						'name' => 'image',
						'label' => 'Image',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cb900997f74',
								'label' => 'Image',
								'name' => 'image',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Image that will be shown',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '60',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54d221bb45227',
								'label' => 'Link URL',
								'name' => 'link_url',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'You may include custom link for this slide (optional)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => 'http://',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54d221f745228',
								'label' => 'Link Target',
								'name' => 'link_target',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Set the link target when user clicks on it',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => 'Open in new window',
								'default_value' => 1,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
				),
				'button_label' => 'Add New',
				'min' => '',
				'max' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-3',
				),
			),
		),
		'menu_order' => 15,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48866e5d',
		'title' => 'Project Gallery',
		'fields' => array(
			array(
				'key' => 'field_54d35e266493e',
				'label' => 'Images Reveal Effect',
				'name' => 'images_reveal_effect',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Choose the effect to show the item images when they appear in viewport.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'none' => 'None',
					'fade' => 'Fade',
					'slidenfade' => 'Slide and Fade',
				),
				'default_value' => 'slidenfade',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d35e2665363',
				'label' => 'Image Spacing',
				'name' => 'image_spacing',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You can either set default image spacing or remove it (merge images).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Default spacing',
					'nospacing' => 'No spacing (merged)',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_585163afa6780',
				'label' => 'Image Captions Position',
				'name' => 'image_captions_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set image captions position for gallery images.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'hover' => 'On hover',
					'below' => 'Below image',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54d35e2665d2d',
				'label' => 'Gallery',
				'name' => 'gallery',
				'aria-label' => '',
				'type' => 'flexible_content',
				'instructions' => 'Select all images you want to show for this portfolio item.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'layouts' => array(
					'layout_5ba0c4886c41c' => array(
						'key' => 'layout_5ba0c4886c41c',
						'name' => 'image',
						'label' => 'Image',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cb900997f76',
								'label' => 'Image',
								'name' => 'image',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Image that will be shown',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '60',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54d3607d85ebd',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54cb903397f75',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d35f0ad6bd0',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c424' => array(
						'key' => 'layout_5ba0c4886c424',
						'name' => 'images_slider',
						'label' => 'Images Slider',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cfacf090385',
								'label' => 'Images',
								'name' => 'images',
								'aria-label' => '',
								'type' => 'gallery',
								'instructions' => 'Select images to include in the slider',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'insert' => 'append',
								'library' => 'all',
								'min' => '',
								'max' => '',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cfad5ffe36f',
								'label' => 'Auto Switch',
								'name' => 'auto_switch',
								'aria-label' => '',
								'type' => 'number',
								'instructions' => 'Set the number of seconds to auto rotate the images',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'default_value' => '',
								'placeholder' => '0 - By default its disabled',
								'prepend' => '',
								'append' => '',
								'min' => 0,
								'max' => '',
								'step' => 1,
							),
							array(
								'key' => 'field_54d360e8e4ee4',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54d3616349420',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d3623b3782b',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c42a' => array(
						'key' => 'layout_5ba0c4886c42a',
						'name' => 'comparison_images',
						'label' => 'Comparison Images',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cbad98dfbf3',
								'label' => 'Image 1',
								'name' => 'image_1',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Assign first image to compare (after)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '30',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54cbadcddfbf4',
								'label' => 'Image 2',
								'name' => 'image_2',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Assign second image to compare (before)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '30',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54d360f6e4ee5',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54d3617449421',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d362383782a',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c42e' => array(
						'key' => 'layout_5ba0c4886c42e',
						'name' => 'youtube_video',
						'label' => 'YouTube Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccacb63b7a4',
								'label' => 'Video URL',
								'name' => 'video_url',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Enter YouTube video URL',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccace109b56',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccae1f11503',
								'label' => 'Video Poster',
								'name' => 'video_poster',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'You can assign video thumbnail (optional)',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_54d35e266493e',
											'operator' => '!=',
											'value' => 'none',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_565317d917df0',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_5653194f280c4',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_5653114034ae3',
								'label' => 'Default YouTube Player',
								'name' => 'default_youtube_player',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Use YouTube default video player',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54d36104e4ee6',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54d3617849422',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d3623637829',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c435' => array(
						'key' => 'layout_5ba0c4886c435',
						'name' => 'vimeo_video',
						'label' => 'Vimeo Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccbeeff2d36',
								'label' => 'Video URL',
								'name' => 'video_url',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Enter Vimeo video URL',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccbeeff2d37',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_5a96757d71e54',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_5a96759571e55',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54d36111e4ee7',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54d3617c49423',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d3623337828',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c43b' => array(
						'key' => 'layout_5ba0c4886c43b',
						'name' => 'selfhosted_video',
						'label' => 'Self-Hosted Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54ccc5b6dd8e8',
								'label' => 'Video',
								'name' => 'video_file',
								'aria-label' => '',
								'type' => 'file',
								'instructions' => 'Upload your own video or select from gallery',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'library' => 'all',
								'min_size' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_54ccc5b6dd8e2',
								'label' => 'Video Resolution',
								'name' => 'video_resolution',
								'aria-label' => '',
								'type' => 'text',
								'instructions' => 'Default is used 16:9',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'placeholder' => '16:9 - Enter in this format {number}:{number}',
								'prepend' => '',
								'append' => '',
								'maxlength' => '',
							),
							array(
								'key' => 'field_54ccc5b6dd8e4',
								'label' => 'Video Poster',
								'name' => 'video_poster',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'You can assign video thumbnail (optional)',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_54d35e266493e',
											'operator' => '!=',
											'value' => 'none',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_56531b3d9059a',
								'label' => 'Auto Play',
								'name' => 'auto_play',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Start playing video when page loads',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_56531bc2f506b',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Replay video over and over',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 0,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_54d3611de4ee8',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_54d3618549424',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_54d3623137827',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_5ba0c4886c442' => array(
						'key' => 'layout_5ba0c4886c442',
						'name' => 'html',
						'label' => 'HTML',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_565f330be5590',
								'label' => 'Content',
								'name' => 'content',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'You can also use shortcodes in this field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 1,
								'delay' => 0,
							),
							array(
								'key' => 'field_565f330be5591',
								'label' => 'Description',
								'name' => 'description',
								'aria-label' => '',
								'type' => 'wysiwyg',
								'instructions' => 'Enter the description for this entry',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 2,
								'default_value' => '',
								'tabs' => 'all',
								'toolbar' => 'full',
								'media_upload' => 0,
								'delay' => 0,
							),
							array(
								'key' => 'field_565f330be5592',
								'label' => 'Description Width',
								'name' => 'description_width',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'How many columns want to have for the description field',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'6-12' => 'Six columns (50%)',
									'5-12' => 'Five columns (40%)',
									'4-12' => 'Four columns (33%)',
								),
								'default_value' => '5-12',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_565f330be5593',
								'label' => 'Description Alignment',
								'name' => 'description_alignment',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Set the alignment for the description text',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'left' => 'Left',
									'right' => 'Right',
								),
								'default_value' => 'left',
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
				),
				'button_label' => 'Add New',
				'min' => '',
				'max' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-4',
				),
			),
		),
		'menu_order' => 16,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c488c86e4',
		'title' => 'Project Gallery',
		'fields' => array(
			array(
				'key' => 'field_54d3abe99ae3e',
				'label' => 'Auto Play',
				'name' => 'auto_play',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set number of seconds to automatically change the slides. Leave empty to disable.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => 7,
				'placeholder' => '',
				'prepend' => 'Seconds:',
				'append' => '',
				'min' => 0,
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_54d3881057933',
				'label' => 'Gallery',
				'name' => 'gallery',
				'aria-label' => '',
				'type' => 'flexible_content',
				'instructions' => 'Select all images you want to show for this portfolio item.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'layouts' => array(
					'layout_5ba0c488ca2a7' => array(
						'key' => 'layout_5ba0c488ca2a7',
						'name' => 'image',
						'label' => 'Image',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_54cb900997f78',
								'label' => 'Image',
								'name' => 'image',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'Image that will be shown',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '60',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
					'layout_6017f4f4a60f0' => array(
						'key' => 'layout_6017f4f4a60f0',
						'name' => 'video',
						'label' => 'Video',
						'display' => 'row',
						'sub_fields' => array(
							array(
								'key' => 'field_601d63cacda63',
								'label' => 'Video Type',
								'name' => 'video_type',
								'aria-label' => '',
								'type' => 'select',
								'instructions' => 'Video provider',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'choices' => array(
									'self-hosted' => 'Self-Hosted Video',
									'youtube' => 'YouTube Video',
								),
								'default_value' => false,
								'allow_null' => 0,
								'multiple' => 0,
								'ui' => 0,
								'return_format' => 'value',
								'ajax' => 0,
								'placeholder' => '',
							),
							array(
								'key' => 'field_6017f4fca60f1',
								'label' => 'Video',
								'name' => 'video_src',
								'aria-label' => '',
								'type' => 'file',
								'instructions' => 'Upload your own video or select from gallery',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_601d63cacda63',
											'operator' => '==',
											'value' => 'self-hosted',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'array',
								'library' => 'all',
								'min_size' => '',
								'max_size' => '',
								'mime_types' => 'mp4,webm,ogv',
							),
							array(
								'key' => 'field_6017fa27fc4ff',
								'label' => 'YouTube Video',
								'name' => 'youtube_url',
								'aria-label' => '',
								'type' => 'oembed',
								'instructions' => 'Alternatively you can insert YouTube video URL',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_601d63cacda63',
											'operator' => '==',
											'value' => 'youtube',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'width' => '',
								'height' => '',
							),
							array(
								'key' => 'field_6017f5a4a60f2',
								'label' => 'Video Poster',
								'name' => 'video_poster',
								'aria-label' => '',
								'type' => 'image',
								'instructions' => 'You can assign video thumbnail (optional)',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => 'retina-thumbnail',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'return_format' => 'id',
								'preview_size' => 'medium',
								'library' => 'all',
								'min_width' => '',
								'min_height' => '',
								'min_size' => '',
								'max_width' => '',
								'max_height' => '',
								'max_size' => '',
								'mime_types' => '',
							),
							array(
								'key' => 'field_6017f5eda60f3',
								'label' => 'Autoplay',
								'name' => 'autoplay',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Play video on slide selection',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 1,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_60180a26855b7',
								'label' => 'Mute',
								'name' => 'mute',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'If "Autoplay" is on, the video will be muted automatically',
								'required' => 0,
								'conditional_logic' => array(
									array(
										array(
											'field' => 'field_6017f5eda60f3',
											'operator' => '!=',
											'value' => '1',
										),
									),
								),
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 1,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_6017f680a60f5',
								'label' => 'Controls',
								'name' => 'controls',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Show video controls such as play button, volume control and progress bar',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 1,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_6017f632a60f4',
								'label' => 'Loop',
								'name' => 'loop',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Loop video infinitely',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 0,
								'ui' => 1,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
							array(
								'key' => 'field_6018105a98ef1',
								'label' => 'Viewport Fit',
								'name' => 'viewport_fit',
								'aria-label' => '',
								'type' => 'true_false',
								'instructions' => 'Cover video to fit viewport width and height',
								'required' => 0,
								'conditional_logic' => 0,
								'wrapper' => array(
									'width' => '',
									'class' => '',
									'id' => '',
								),
								'wpml_cf_preferences' => 1,
								'message' => '',
								'default_value' => 1,
								'ui' => 1,
								'ui_on_text' => '',
								'ui_off_text' => '',
							),
						),
						'min' => '',
						'max' => '',
					),
				),
				'button_label' => 'Add New',
				'min' => '',
				'max' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
				array(
					'param' => 'portfolio_item_type',
					'operator' => '==',
					'value' => 'type-5',
				),
			),
		),
		'menu_order' => 17,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5fc75ed114e2b',
		'title' => 'Featured Video',
		'fields' => array(
			array(
				'key' => 'field_5fc760ffc0a20',
				'label' => 'Featured Video',
				'name' => 'featured_video',
				'aria-label' => '',
				'type' => 'repeater',
				'instructions' => 'Assign self hosted video as featured video of this portfolio item. Adding featured video will replace Featured Image.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'collapsed' => '',
				'min' => 0,
				'max' => 0,
				'layout' => 'table',
				'button_label' => 'Add Video',
				'rows_per_page' => 20,
				'sub_fields' => array(
					array(
						'key' => 'field_5fc765f7c6ad1',
						'label' => 'Video Source',
						'name' => 'src',
						'aria-label' => '',
						'type' => 'file',
						'instructions' => 'Select MP4, OGG or WEBM file types.',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'return_format' => 'array',
						'library' => 'all',
						'min_size' => '',
						'max_size' => '',
						'mime_types' => 'mp4,webm,ogv',
						'parent_repeater' => 'field_5fc760ffc0a20',
					),
				),
			),
			array(
				'key' => 'field_60111d98a5e48',
				'label' => 'Autoplay',
				'name' => 'featured_video_autoplay',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'If set to autoplay, video will be muted and auto play when visible on viewport.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 1,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_60142273e7af8',
				'label' => 'Mute',
				'name' => 'featured_video_mute',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Toggle audio output of the video. If "Autoplay" is on, the video will be muted automatically.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_60111d98a5e48',
							'operator' => '!=',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_60111df4a5e49',
				'label' => 'Controls',
				'name' => 'featured_video_controls',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Show video controls such as play button, volume control and progress bar. If checked, hover layer will not be shown.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_601131669acfd',
				'label' => 'Loop',
				'name' => 'featured_video_loop',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Loop video infinitely.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
		),
		'menu_order' => 18,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c488dda57',
		'title' => 'Page Options',
		'fields' => array(
			array(
				'key' => 'field_54ff2a9a91b27',
				'label' => 'Header Options',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54ff2aa491b28',
				'label' => 'Header Position',
				'name' => 'header_position',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set header position (logo and menu).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'static' => 'Content Below (Static)',
					'absolute' => 'Over the Content (Absolute)',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54ff2fb44fa6c',
				'label' => 'Header Spacing',
				'name' => 'header_spacing',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'If Header Position is set to "Over the Content" this setting will take effect. Unit is Pixels',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54ff2aa491b28',
							'operator' => '==',
							'value' => 'absolute',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => 0,
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_57308bbb00a7f',
				'label' => 'Full-width Header',
				'name' => 'header_fullwidth',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Extend header container to the browser edge.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5d4c03a936beb',
				'label' => 'Header Styling',
				'name' => 'page_header_styling',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Apply custom header styling for this page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5d4c0482990d2',
				'label' => 'Header Background Color',
				'name' => 'header_background_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Optionally you can add or overwrite background color for header container with this option. Leave empty to use default value.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5d4c03a936beb',
							'operator' => '==',
							'value' => 'yes',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_5d4c0b57caf84',
				'label' => 'Header Bottom Border',
				'name' => 'header_bottom_border',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Optionally you can add or overwrite bottom border color for header container with this option. Leave empty to use default value.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5d4c03a936beb',
							'operator' => '==',
							'value' => 'yes',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_5d4c0b7ecaf85',
				'label' => 'Header Bottom Spacing',
				'name' => 'header_bottom_spacing',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Optionally you can add or overwrite bottom border spacing for header container with this option. Leave empty to use default value.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5d4c03a936beb',
							'operator' => '==',
							'value' => 'yes',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_54e6225f20eab',
				'label' => 'Heading Title',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54e6228220eac',
				'label' => 'Heading Title',
				'name' => 'heading_title',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Show or hide page heading title. Note that this setting may not be supported for some pages.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => 'Show page heading title',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_54e6230120ead',
				'label' => 'Page Title Type',
				'name' => 'page_heading_title_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Use this post title or shown your custom title.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54e6228220eac',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'post_title' => 'Show this post title',
					'custom_title' => 'Enter custom title',
				),
				'default_value' => 'post_title',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54e6235f20eae',
				'label' => 'Page Heading Title',
				'name' => 'page_heading_custom_title',
				'aria-label' => '',
				'type' => 'text',
				'instructions' => 'Enter your custom page heading title',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54e6230120ead',
							'operator' => '==',
							'value' => 'custom_title',
						),
						array(
							'field' => 'field_54e6228220eac',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => '',
				'maxlength' => '',
			),
			array(
				'key' => 'field_54e623e11c9ee',
				'label' => 'Page Heading Description Type',
				'name' => 'page_heading_description_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Use post content as description or enter custom description.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54e6228220eac',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'post_content' => 'Use this post description',
					'custom' => 'Enter custom description',
				),
				'default_value' => 'custom',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54e624c21c9ef',
				'label' => 'Page Heading Description',
				'name' => 'page_heading_custom_description',
				'aria-label' => '',
				'type' => 'textarea',
				'instructions' => 'Enter your custom page heading description here. (Optional)',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54e623e11c9ee',
							'operator' => '==',
							'value' => 'custom',
						),
						array(
							'field' => 'field_54e6228220eac',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'maxlength' => '',
				'rows' => 5,
				'new_lines' => '',
			),
			array(
				'key' => 'field_55b160c4edb8a',
				'label' => 'Logo & Menu',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_55b160d6edb8b',
				'label' => 'Custom Logo',
				'name' => 'custom_logo',
				'aria-label' => '',
				'type' => 'image',
				'instructions' => 'Use custom logo for this page only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => 'retina-thumbnail',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'id',
				'preview_size' => 'medium',
				'library' => 'all',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
			array(
				'key' => 'field_55b160f3edb8c',
				'label' => 'Custom Logo Width',
				'name' => 'custom_logo_width',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'You can the set maximum width in pixels for the uploaded logo, mostly used when you use upload retina (@2x) logo. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => 'Example: 50',
				'prepend' => '',
				'append' => 'px',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_55b163b52c685',
				'label' => 'Custom Menu Skin',
				'name' => 'custom_menu_skin',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Custom menu skin this page only',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Use from Theme Options',
					'menu-skin-main' => 'Default (Primary Theme Color)',
					'menu-skin-dark' => 'Black (Dark)',
					'menu-skin-light' => 'White (Light)',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_55b1663309efd',
				'label' => 'Sticky Header',
				'name' => 'sticky_menu_on_page',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You can enable or disable sticky header on this page only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Use from Theme Options',
					'enable' => 'Enable',
					'disable' => 'Disable',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5836f17c44f7f',
				'label' => 'Custom Sticky Logo',
				'name' => 'custom_sticky_logo',
				'aria-label' => '',
				'type' => 'image',
				'instructions' => 'Use custom logo for sticky header in this page only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => 'retina-thumbnail',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'return_format' => 'id',
				'preview_size' => 'medium',
				'library' => 'all',
				'min_width' => '',
				'min_height' => '',
				'min_size' => '',
				'max_width' => '',
				'max_height' => '',
				'max_size' => '',
				'mime_types' => '',
			),
			array(
				'key' => 'field_56150e4825cef',
				'label' => 'Sticky Header Skin',
				'name' => 'sticky_menu_skin',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set menu skin when sticky header is activated (applied only if sticky menu is enabled)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Use from Theme Options',
					'menu-skin-main' => 'Default (Primary Theme Color)',
					'menu-skin-dark' => 'Black (Dark)',
					'menu-skin-light' => 'White (Light)',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_58382d561e98d',
				'label' => 'Logo Switch',
				'name' => 'section_logo_switch',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Switch header logo and styles on specific sections or sliders.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_58382e9f2830e',
				'label' => 'Section Logo Switch',
				'name' => 'logo_switch_sections',
				'aria-label' => '',
				'type' => 'repeater',
				'instructions' => 'Switch logo and header style on specific sections or slider of page.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_58382d561e98d',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'collapsed' => '',
				'min' => 0,
				'max' => 0,
				'layout' => 'row',
				'button_label' => 'Add Logo Switch Section',
				'rows_per_page' => 20,
				'sub_fields' => array(
					array(
						'key' => 'field_58382f5bd4c4a',
						'label' => 'Switch Type',
						'name' => 'switch_type',
						'aria-label' => '',
						'type' => 'select',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'choices' => array(
							'section' => 'Section',
							'revslider' => 'Revolution Slider',
						),
						'default_value' => 'section',
						'allow_null' => 0,
						'multiple' => 0,
						'ui' => 0,
						'return_format' => 'value',
						'ajax' => 0,
						'placeholder' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_58382feb87c5a',
						'label' => 'Section ID',
						'name' => 'section_id',
						'aria-label' => '',
						'type' => 'text',
						'instructions' => 'Target to HTML element',
						'required' => 0,
						'conditional_logic' => array(
							array(
								array(
									'field' => 'field_58382f5bd4c4a',
									'operator' => '==',
									'value' => 'section',
								),
							),
						),
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 2,
						'default_value' => '',
						'placeholder' => 'my-section-1',
						'prepend' => '#',
						'append' => '',
						'maxlength' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_583832b3d951e',
						'label' => 'Slider',
						'name' => 'revslider',
						'aria-label' => '',
						'type' => 'revsliders',
						'instructions' => '',
						'required' => 0,
						'conditional_logic' => array(
							array(
								array(
									'field' => 'field_58382f5bd4c4a',
									'operator' => '==',
									'value' => 'revslider',
								),
							),
						),
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 2,
						'default_value' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_5e29c309bd0f5',
						'label' => 'Slide Index',
						'name' => 'slide_index',
						'aria-label' => '',
						'type' => 'text',
						'instructions' => 'Specify slide index to apply the header style. Leave blank to apply for all slides.',
						'required' => 0,
						'conditional_logic' => array(
							array(
								array(
									'field' => 'field_58382f5bd4c4a',
									'operator' => '==',
									'value' => 'revslider',
								),
							),
						),
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 2,
						'default_value' => '',
						'placeholder' => 'Starts from 1',
						'prepend' => '',
						'append' => '',
						'maxlength' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_583830b862c12',
						'label' => 'Logo',
						'name' => 'logo',
						'aria-label' => '',
						'type' => 'image',
						'instructions' => 'Upload custom logo for this section/slide',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => 'retina-thumbnail',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'return_format' => 'array',
						'preview_size' => 'medium',
						'library' => 'all',
						'min_width' => '',
						'min_height' => '',
						'min_size' => '',
						'max_width' => '',
						'max_height' => '',
						'max_size' => '',
						'mime_types' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_583833540e070',
						'label' => 'Logo Width',
						'name' => 'logo_width',
						'aria-label' => '',
						'type' => 'number',
						'instructions' => 'Optional',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'default_value' => '',
						'placeholder' => '',
						'prepend' => '',
						'append' => '',
						'min' => '',
						'max' => '',
						'step' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_583830f762c13',
						'label' => 'Menu Skin',
						'name' => 'menu_skin',
						'aria-label' => '',
						'type' => 'select',
						'instructions' => 'Select menu skin for this section/slide',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'choices' => array(
							'current' => 'Use current menu skin',
							'menu-skin-main' => 'Default (Primary Theme Color)',
							'menu-skin-dark' => 'Black (Dark)',
							'menu-skin-light' => 'White (Light)',
						),
						'default_value' => 'current',
						'allow_null' => 0,
						'multiple' => 0,
						'ui' => 0,
						'return_format' => 'value',
						'ajax' => 0,
						'placeholder' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
					array(
						'key' => 'field_5838316262c14',
						'label' => 'Transparent',
						'name' => 'transparent_style',
						'aria-label' => '',
						'type' => 'true_false',
						'instructions' => 'Set transparent header style',
						'required' => 0,
						'conditional_logic' => 0,
						'wrapper' => array(
							'width' => '',
							'class' => '',
							'id' => '',
						),
						'wpml_cf_preferences' => 1,
						'message' => 'Transparent header background, borders and shadow',
						'default_value' => 0,
						'ui' => 0,
						'ui_on_text' => '',
						'ui_off_text' => '',
						'parent_repeater' => 'field_58382e9f2830e',
					),
				),
			),
			array(
				'key' => 'field_564dd7b114e58',
				'label' => 'Footer Options',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_564dd7d814e59',
				'label' => 'Footer Visibility',
				'name' => 'footer_visibility',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Show or hide footer on this specific page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'show' => 'Show footer on this page',
					'hide' => 'Hide footer on this page',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_564ddabeae7a1',
				'label' => 'Fixed Footer',
				'name' => 'fixed_footer',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'You can overwrite the footer type for this page/post only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'normal' => 'Normal',
					'fixed' => 'Fixed to Bottom (No animations)',
					'fixed-fade' => 'Fixed to Bottom with Fade Animation',
					'fixed-slide' => 'Fixed to Bottom with Slide Animation',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5738346a2826f',
				'label' => 'Full-width Footer',
				'name' => 'footer_fullwidth',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Extend footer container to the browser edge.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'yes' => 'Yes',
					'no' => 'No',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5f05d808ad43f',
				'label' => 'Other Options',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_5f05d8b0ad442',
				'label' => 'Custom Grid Container Width',
				'name' => 'custom_grid_container_width',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Set custom grid container width for this page.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_5f05d81cad440',
				'label' => 'Grid Container Width',
				'name' => 'grid_container_width',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set maximum grid container width.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f05d8b0ad442',
							'operator' => '==',
							'value' => '1',
						),
						array(
							'field' => 'field_5f05d85bad441',
							'operator' => '!=',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => 1170,
				'prepend' => '',
				'append' => 'px',
				'min' => 0,
				'max' => '',
				'step' => 1,
			),
			array(
				'key' => 'field_5f05d85bad441',
				'label' => 'Fullwidth container',
				'name' => 'grid_container_fullwidth',
				'aria-label' => '',
				'type' => 'true_false',
				'instructions' => 'Checking this option will overwrite Grid Container Width value.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f05d8b0ad442',
							'operator' => '==',
							'value' => '1',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'message' => '',
				'default_value' => 0,
				'ui' => 1,
				'ui_on_text' => '',
				'ui_off_text' => '',
			),
			array(
				'key' => 'field_5f0eb10034cc3',
				'label' => 'Breadcrumb',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_5f0eb02291127',
				'label' => 'Breadcrumb',
				'name' => 'breadcrumb',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Override breadcrumb settings for this current page. Breadcrumb NavXT plugin must be installed and active.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Inherit from Theme Options',
					'enable' => 'Enable',
					'disable' => 'Disable',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_5f0ebabc8e07c',
				'label' => 'Background Color',
				'name' => 'breadcrumb_background_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Set custom background color. Leave empty to inherit the value from Theme Options.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_5f0ebb2c8e07d',
				'label' => 'Text Color',
				'name' => 'breadcrumb_text_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Set custom text color. Leave empty to inherit the value from Theme Options.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_5f0ebb668e07e',
				'label' => 'Border Color',
				'name' => 'breadcrumb_border_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'Set custom border color. Leave empty to inherit the value from Theme Options.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
						array(
							'field' => 'field_5f0ebbd68e07f',
							'operator' => '==contains',
							'value' => 'border',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_5f0ebbd68e07f',
				'label' => 'Border Type',
				'name' => 'breadcrumb_border_type',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set custom border type. Leave empty to inherit the value from Theme Options.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Inherit from Theme Options',
					'' => 'No border',
					'border' => 'Full Border',
					'border-horizontal' => 'Horizontal Border',
				),
				'default_value' => false,
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_601ab59cd7063',
				'label' => 'Border Radius',
				'name' => 'breadcrumb_border_radius',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set custom border radius (optional).',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => 0,
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_601aba3d483e0',
				'label' => 'Top Margin',
				'name' => 'breadcrumb_margin_top',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set custom top margin (optional).',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_601aba7883fd6',
				'label' => 'Bottom Margin',
				'name' => 'breadcrumb_margin_bottom',
				'aria-label' => '',
				'type' => 'number',
				'instructions' => 'Set custom bottom margin (optional).',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'placeholder' => '',
				'prepend' => '',
				'append' => 'px',
				'min' => '',
				'max' => '',
				'step' => '',
			),
			array(
				'key' => 'field_5f0eb12dc9607',
				'label' => 'Text Alignment',
				'name' => 'breadcrumb_text_alignment',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set text alignment of breadcrumb trail.',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_5f0eb02291127',
							'operator' => '==',
							'value' => 'enable',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Inherit from Theme Options',
					'left' => 'Left',
					'center' => 'Center',
					'right' => 'Right',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'page',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
			),
		),
		'menu_order' => 19,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c488cf1ee',
		'title' => 'Other Settings',
		'fields' => array(
			array(
				'key' => 'field_54db76b925fcd',
				'label' => 'Custom Hover Background Color',
				'name' => 'custom_hover_background_color',
				'aria-label' => '',
				'type' => 'color_picker',
				'instructions' => 'You can set custom layer hover color for this portfolio item specifically. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'default_value' => '',
				'enable_opacity' => false,
				'return_format' => 'string',
			),
			array(
				'key' => 'field_54e5e86bfa3e5',
				'label' => 'Hover Effect Style',
				'name' => 'hover_effect_style',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set hover effect style for this item only. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'none' => 'No hover effect',
					'full' => 'Full background hover',
					'distanced' => 'Distanced background hover',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db78fc4002d',
				'label' => 'Hover Color Transparency',
				'name' => 'hover_color_transparency',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Apply custom opacity settings for hover layer on this portfolio item only. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'opacity' => 'Apply Transparency',
					'no-opacity' => 'No Transparency',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54db814e2d5a7',
				'label' => 'Hover Layer Options',
				'name' => 'hover_layer_options',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Set initial state for hover layer, this setting is applied only for some portfolio types. (Optional)',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'normal' => 'Normal',
					'none' => 'No hover layer',
					'always-hover' => 'Always show hover layer',
					'hover-reverse' => 'Hide hover layer on hover (reverse state)',
				),
				'default_value' => 'normal',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
		),
		'menu_order' => 20,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c4893cf5d',
		'title' => 'Post Settings',
		'fields' => array(
			array(
				'key' => 'field_54be705f09c1f',
				'label' => 'Featured Image',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
			),
			array(
				'key' => 'field_54be6ff6e5b9b',
				'label' => 'Featured Image Placing',
				'name' => 'featured_image_placing',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Select where you want to display the thumbnail (or post content format).',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'default' => 'Use from Theme Options',
					'container' => 'Within Container',
					'full-width' => 'Full width',
					'hide' => 'Hide Featured Image',
				),
				'default_value' => 'default',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_54be714688863',
				'label' => 'Image Size',
				'name' => 'post_image_size',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => array(
					array(
						array(
							'field' => 'field_54be6ff6e5b9b',
							'operator' => '!=',
							'value' => 'hide',
						),
					),
				),
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 1,
				'choices' => array(
					'inherit' => 'Use from Theme Options',
					'default' => 'Default Thumbnail Size',
					'full' => 'Original Image Size',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
			),
			array(
				'key' => 'field_619ba118519cf',
				'label' => 'Related Posts',
				'name' => '',
				'aria-label' => '',
				'type' => 'tab',
				'instructions' => '',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'placement' => 'top',
				'endpoint' => 0,
				'selected' => 0,
				'wpml_cf_preferences' => 1,
			),
			array(
				'key' => 'field_619ba131519d0',
				'label' => 'Show Related Posts',
				'name' => 'related_posts_visibility',
				'aria-label' => '',
				'type' => 'select',
				'instructions' => 'Show or hide related posts for this post only.',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'choices' => array(
					'inherit' => 'Inherit from Theme Options',
					'visible' => 'Show Related Products',
					'hidden' => 'Hide Related Products',
				),
				'default_value' => 'inherit',
				'allow_null' => 0,
				'multiple' => 0,
				'ui' => 0,
				'return_format' => 'value',
				'ajax' => 0,
				'placeholder' => '',
				'wpml_cf_preferences' => 1,
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
			),
		),
		'menu_order' => 21,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );

	acf_add_local_field_group( array(
		'key' => 'group_5ba0c48949e0a',
		'title' => 'Custom CSS',
		'fields' => array(
			array(
				'key' => 'field_567020fe8e640',
				'label' => 'Custom Page Style',
				'name' => 'page_custom_css',
				'aria-label' => '',
				'type' => 'textarea',
				'instructions' => 'Apply custom CSS only for this page. 
<br>
<small>Note: You don\'t need to wrap it with <strong>style</strong> tags (HTML is not allowed in this field).</small>',
				'required' => 0,
				'conditional_logic' => 0,
				'wrapper' => array(
					'width' => '',
					'class' => '',
					'id' => '',
				),
				'wpml_cf_preferences' => 2,
				'default_value' => '',
				'placeholder' => '',
				'maxlength' => '',
				'rows' => 15,
				'new_lines' => '',
			),
		),
		'location' => array(
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'page',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'portfolio',
				),
			),
			array(
				array(
					'param' => 'post_type',
					'operator' => '==',
					'value' => 'post',
				),
			),
		),
		'menu_order' => 22,
		'position' => 'normal',
		'style' => 'default',
		'label_placement' => 'top',
		'instruction_placement' => 'label',
		'hide_on_screen' => '',
		'active' => true,
		'description' => '',
		'show_in_rest' => 0,
		'acfml_field_group_mode' => 'translation',
	) );
} );
